ELEC2645 (2018/19) / Mbed 2 deprecated el17st

Dependencies:   mbed FATFileSystem

Revision:
17:7d4d8905b608
Parent:
13:95323e0f2fcb
Child:
18:14e5391beccf
--- a/CaMove/CaMove.h	Tue May 07 21:26:26 2019 +0000
+++ b/CaMove/CaMove.h	Wed May 08 00:30:09 2019 +0000
@@ -13,14 +13,14 @@
 //Required Libraries
 #include "mbed.h"
 #include "CaMove.h"
-#include "N5110.h"
+#include "Bitmap.h"
 #include "SDFileSystem.h"
 
 //Define SD Card
 SDFileSystem sd(PTE3, PTE1, PTE2, PTE4, "sd");
 
 //Define LCD
-N5110 lcd(PTC9,PTC0,PTC7,PTD2,PTD1,PTC11);
+Bitmap lcd(PTC9,PTC0,PTC7,PTD2,PTD1,PTC11);
 
 //Define CaMove
 CaMove CM(PTB9,PTB11,PTB10);
@@ -86,7 +86,6 @@
 */
 
 #include "mbed.h"
-#include "N5110.h"
 #include "Bitmap.h"
 #include <vector>
 
@@ -123,10 +122,10 @@
     void init(int x,int y,Direction D);
     /** Function that moves the charater but also manages all animations related to its movement and collisions. Double Black lines cannot be crossed and Single Black lines can only be crossed one way.
      *
      *@param lcd N5110 Class Object.
      *
      */
-    void move(N5110 &lcd);
+    void move(Bitmap &lcd);
     /** Function to check if charater is in the screen.
      *
      *@return Returns true if charater is on the screen otherwise false.
@@ -165,9 +164,9 @@
      */
     void spawn(int x, int y);
     /** Function that moves the Charater per Frame.
      *@param lcd The N5110 class object.
      */
-    void chase(N5110 &lcd, int girl);
+    void chase(Bitmap &lcd, int girl);
     /** Function that tell if the player is caught by chaser Charater.
      *@returns Returns a boolean true is caught and false if not.
      */
@@ -189,7 +188,7 @@
     //Volatile variables for ISR Interrupts
     volatile int _treg;
     volatile bool _trg;
-    void rend(N5110 &lcd);
+    void rend(Bitmap &lcd);
     //AI Componets
     bool enabled;
     int _ch;
@@ -123,10 +122,10 @@
     /** Function that moves the charater but also manages all animations related to its movement and collisions. Double Black lines cannot be crossed and Single Black lines can only be crossed one way.
      *
-     *@param lcd N5110 Class Object.
+     *@param lcd Bitmap Class Object.
      *
      */
@@ -165,9 +164,9 @@
     void spawn(int x, int y);
     /** Function that moves the Charater per Frame.
-     *@param lcd The N5110 class object.
+     *@param lcd The Bitmap class object.
      */